==> miniorange_oauth_client-4.0.2.tar.gz: miniorange_oauth_client/src/Form/MiniorangeMapping.php <==
<?php

/**
 * @file
 * Contains \Drupal\miniorange_oauth_client\Form\MiniorangeGeneralSettings.
 */

namespace Drupal\miniorange_oauth_client\Form;
use Drupal\Component\Serialization\Json;
use Drupal\Core\Form\FormStateInterface;
use Drupal\miniorange_oauth_client\mo_saml_visualTour;
use Drupal\miniorange_oauth_client\Utilities;
use Drupal\Core\Form\FormBase;

class MiniorangeMapping extends FormBase
{

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'miniorange_mapping';
  }


  public function buildForm(array $form, FormStateInterface $form_state)
  {
      global $base_url;

      $moTour = mo_saml_visualTour::genArray();
      $form['tourArray'] = array(
          '#type' => 'hidden',
          '#value' => $moTour,
      );

      $form['markup_library'] = array(
        '#attached' => array(
            'library' => array(
                "miniorange_oauth_client/miniorange_oauth_client.admin",
                "miniorange_oauth_client/miniorange_oauth_client.style_settings",
                "miniorange_oauth_client/miniorange_oauth_client.Vtour",
                "miniorange_oauth_client/miniorange_oauth_client.slide_support_button",
            )
        ),
      );

      $config = \Drupal::config('miniorange_oauth_client.settings');

      $form['header_top_style_1'] = array('#markup' => '<div class="mo_oauth_table_layout_1">');

      $form['markup_top'] = array(
          '#markup' => '<div class="mo_oauth_table_layout mo_oauth_container">',
      );

      $form['markup_tour_button'] = array(
          '#markup' => '<a id="Restart_moTour" class="button button--primary mo_oauth_btn_restart_tour">Take a Tour</a><br><br><br>',
      );

      $form['markup_top_vt_start'] = array(
        '#type' => 'fieldset',
        '#title' => t('ATTRIBUTE MAPPING'),
      );

      $url_path = $base_url . '/' . \Drupal::service('extension.list.module')->getPath('miniorange_oauth_client'). '/includes/images';

      $email_attr = $config->get('miniorange_oauth_client_email_attr_val');
      $name_attr = $config->get('miniorange_oauth_client_name_attr_val');

      $form['markup_top_vt_start']['mo_vt_id_start1'] = array(
          '#markup' => '<hr><br>
            <div class="mo_oauth_highlight_background_note_1">Attributes are the user details that are stored by your OAuth server(s). Attribute Mapping helps you get user attributes/fields from your OAuth server and map them to your Drupal site user attributes.</div>
            <br><b>Note: </b>Please select the attribute name with email and Username from the dropdown of Received Attribute List for successful SSO. If your desired attribute is not listed in the dropdown, please select Other in the dropdown and then enter the desired attribute in the text-field.<br><br>',
      );

      $attrs = $config->get('miniorange_oauth_client_attr_list_from_server');
     
      if(isset($attrs))
      $attrs = JSON::decode($attrs);
      $options = array();
      if (is_array($attrs)) {
        foreach ($attrs as $key => $value) {
          if (is_array($value)){
            foreach ($value as $key1 => $value1) {
              $options[$key1] = $key1;
            }
            continue;
          }
          $options[$key] = $key;
        }
      }
      $options['other'] = 'Other';
      $other_email_attr = $email_attr == 'other' ? $config->get('miniorange_oauth_client_other_field_for_email') : '';
      $other_name_attr = $name_attr == 'other' ? $config->get('miniorange_oauth_client_other_field_for_name') : '';
      $data = ['email_attr' => 'miniorange_oauth_client_email_attr_val', 'name_attr' => 'miniorange_oauth_client_name_attr_val'];

      $form['markup_top_vt_start']['miniorange_oauth_login_mapping'] = array(
          '#type' => 'table',
          '#responsive' => TRUE,
          '#header' => [
              t('Attributes'),
              t('Received Attribute List'),
              t('If Other selected'),
          ],
          '#attributes' => ['style' => 'border-collapse: separate;'],
      );

      foreach ($data as $key => $value) {
          $row = self::miniorange_oauth_client_table_data_mapping($key, $value, $options, $config, $other_email_attr, $other_name_attr);
          $form['markup_top_vt_start']['miniorange_oauth_login_mapping'][$key] = $row;
      }

      $form['markup_top_vt_start']['miniorange_oauth_client_attr_setup_button_2'] = array(
        '#type' => 'submit',
        '#button_type' => 'primary',
        '#value' => t('Save Configuration'),
        '#prefix' => '<br>',
        '#attributes' => array('style' => '	margin: auto; display:block; '),
        '#submit' => array('::miniorange_oauth_client_attr_setup_submit'),
      );

    $form['markup_custom_attribute'] = array(
        '#type' => 'fieldset',
        '#title' => t('CUSTOM ATTRIBUTE MAPPING <a href="licensing"><img class="mo_oauth_pro_icon1" src="' . $url_path . '/pro.png" alt="Premium and Enterprise"><span class="mo_pro_tooltip">Available in the Standard, Premium and Enterprise version</span></a><a class="mo_oauth_client_how_to_setup" href="https://developers.miniorange.com/docs/oauth-drupal/mapping#attribute-mapping" target="_blank">[What is Attribute Mapping and How to Set up]</a>'),
      );

      $form['markup_custom_attribute']['attribute_mapping_info'] = array(
      '#markup' => t('<hr><br><div class="mo_oauth_highlight_background_note_1"> In addition to the default email and username attributes, the functionality of custom attribute mapping is provided in the <a href="' . $base_url . '/admin/config/people/miniorange_oauth_client/licensing">Standard, Premium and Enterprise</a> version of the module. One can map fields like contact number, first name, last name or any other attribute using the custom attribute mapping feature.</div>')
    );

      $form['markup_custom_attribute']['markup_cam'] = array(
        '#markup' => '<br><div class="mo_oauth_highlight_background_note_1">One should note that the attribute name has to be the machine name assigned automatically and not the Label of the attribute. </div><br>',
      );

      $form['markup_custom_attribute']['miniorange_oauth_attr_name'] = array(
          '#type' => 'textfield',
          '#prefix' => '<div><table><tr><td>',
          '#suffix' => '</td>',
          '#id' => 'text_field1',
          '#title' => t('OAuth Server Attribute Name 1'),
          '#attributes' => array('style' => 'width:73%;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'OAuth Server Attribute Name'),
          '#required' => FALSE,
          '#disabled' => TRUE,
      );
      $form['markup_custom_attribute']['miniorange_oauth_server_name'] = array(
          '#type' => 'textfield',
          '#id' => 'text_field2',
          '#prefix' => '<td>',
          '#suffix' => '</td>',
          '#title' => t('Attribute Name 1'),
          '#attributes' => array('style' => 'width:73%;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Attribute Name'),
          '#required' => FALSE,
          '#disabled' => TRUE,
      );
      $form['markup_custom_attribute']['miniorange_oauth_add_name'] = array(
          '#prefix' => '<td>',
          '#suffix' => '</td>',
          '#type' => 'button',
          '#disabled' => 'true',
          '#attributes' => array('style' => 'background-color: lightgreen;color:white'),
          '#value' => '+',
      );
      $form['markup_custom_attribute']['miniorange_oauth_sub_name'] = array(
          '#prefix' => '<td>',
          '#suffix' => '</td></tr></table></div>',
          '#type' => 'button',
          '#disabled' => 'true',
          '#attributes' => array('style' => 'background-color: red;color:white'),
          '#value' => '-',
      );

    $form['markup_custom_role_mapping'] = array(
        '#type' => 'fieldset',
        '#title' => t('CUSTOM ROLE MAPPING <a href="licensing"><img class="mo_oauth_pro_icon1" src="' . $url_path . '/pro.png" alt="Premium and Enterprise"><span class="mo_pro_tooltip">Available in the Premium and Enterprise version</span></a><a class="mo_oauth_client_how_to_setup" href="https://developers.miniorange.com/docs/oauth-drupal/mapping#role-mapping" target="_blank">[What is Role Mapping and How to Set up]</a>'),
    );

     $form['markup_custom_role_mapping']['role_mapping_info'] = array(
      '#markup' => '<hr><br><div class="mo_oauth_highlight_background_note_1">This feature allows you to automatically map OAuth Server roles/groups to below selected Drupal Role. For step by step instructions on how to map the roles, please refer to our guide from the link<a href="https://developers.miniorange.com/docs/oauth-drupal/mapping#role-mapping" target="_blank"> HERE</a>.</div>',
    );

      $form['markup_custom_role_mapping']['miniorange_disable_attribute'] = array(
        '#type' => 'checkbox',
        '#title' => t('Do not update existing user&#39;s role.'),
	    '#disabled' => TRUE,
        '#prefix' => '<br>',
      );

      $form['markup_custom_role_mapping']['miniorange_oauth_disable_role_update'] = array(
        '#type' => 'checkbox',
        '#title' => t('Check this option if you do not want to update user role if roles not mapped.'),
	    '#disabled' => TRUE,
      );

      $mrole= user_role_names($membersonly = TRUE);
      $drole = array_values($mrole);

      $form['markup_custom_role_mapping']['miniorange_oauth_default_mapping'] = array(
          '#type' => 'select',
          '#id' => 'miniorange_oauth_client_app',
          '#title' => t('Select default group for the new users'),
          '#options' => $mrole,
          '#default_value' => $drole,
          '#attributes' => array('style' => 'width:73%;'),
          '#disabled' => TRUE,
      );

      foreach($mrole as $roles) {
          $rolelabel = str_replace(' ','',$roles);
          $form['markup_custom_role_mapping']['miniorange_oauth_role_' . $rolelabel] = array(
              '#type' => 'textfield',
              '#title' => t($roles),
              '#default_value' => \Drupal::config('miniorange_oauth_client.settings')->get('miniorange_oauth_role_' . $rolelabel, ''),
              '#attributes' => array('style' => 'width:73%;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Semi-colon(;) separated Group/Role value for ' . $roles),
              '#disabled' => TRUE,
          );
      }

      $form['markup_custom_login_logout'] = array(
          '#type' => 'fieldset',
          '#title' => t('CUSTOM LOGIN/LOGOUT <a href="licensing"><img class="mo_oauth_pro_icon1" src="' . $url_path . '/pro.png" alt="Premium and Enterprise"><span class="mo_pro_tooltip">Available in the Standard, Premium and Enterprise version</span></a>'),
      );

      $form['markup_custom_login_logout']['miniorange_oauth_client_login_url'] = array(
          '#type' => 'textfield',
          '#disabled' => TRUE,
          '#title' => t('Default redirect URL after login'),
          '#attributes' => array('style' => 'width:73%;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Login URL'),
          '#prefix' => '<hr><br>',
      );

      $form['markup_custom_login_logout']['miniorange_oauth_client_logout_url'] = array(
          '#type' => 'textfield',
          '#disabled' => TRUE,
          '#title' => t('Default redirect URL after logout'),
          '#attributes' => array('style' => 'width:73%;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Logout URL'),
      );

      $form['markup_custom_login_logout']['markup_role_break'] = array(
          '#markup' => '<br>',
      );

      $form['markup_custom_login_logout']['miniorange_oauth_client_attr_setup_button'] = array(
        '#type' => 'submit',
        '#button_type' => 'primary',
        '#value' => t('Save Configuration'),
        '#attributes' => array('style' => '	margin: auto; display:block; '),
        '#disabled' => TRUE,
      );

      $form['markup_custom_login_logout']['mo_header_style_end'] = array('#markup' => '</div>');

      Utilities::show_attr_list_from_idp($form, $form_state);

      $form['miniorange_idp_guide_link_end'] = array(
          '#markup' => '</div>',
      );

      Utilities::moOAuthShowCustomerSupportIcon($form, $form_state);

      return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {

  }

  function miniorange_oauth_client_attr_setup_submit($form, $form_state)
  {
      $form_values = $form_state->getValues();
      $email_attr = $form_values['miniorange_oauth_login_mapping']['email_attr']['miniorange_oauth_client_email_select'];
      $name_attr = $form_values['miniorange_oauth_login_mapping']['name_attr']['miniorange_oauth_client_username_select'];
      $app_name = \Drupal::config('miniorange_oauth_client.settings')->get('miniorange_auth_client_app_name');

      $app_values = \Drupal::config('miniorange_oauth_client.settings')->get('miniorange_oauth_client_appval');

      if ($email_attr == 'other'){
         $other_email_attr = trim($form_values['miniorange_oauth_login_mapping']['email_attr']['miniorange_oauth_client_email_attr']);
         $app_values['miniorange_oauth_client_email_attr'] = $other_email_attr;
         \Drupal::configFactory()->getEditable('miniorange_oauth_client.settings')->set('miniorange_oauth_client_other_field_for_email', $other_email_attr)->save();
      }
      else{
        $app_values['miniorange_oauth_client_email_attr'] = $email_attr;
      }

      if ($name_attr == 'other'){
        $other_name_attr = trim($form_values['miniorange_oauth_login_mapping']['name_attr']['miniorange_oauth_client_name_attr']);
        $app_values['miniorange_oauth_client_name_attr'] = $other_name_attr;
        \Drupal::configFactory()->getEditable('miniorange_oauth_client.settings')->set('miniorange_oauth_client_other_field_for_name', $other_name_attr)->save();
      }
      else{
        $app_values['miniorange_oauth_client_name_attr'] = $name_attr;
      }


      \Drupal::configFactory()->getEditable('miniorange_oauth_client.settings')->set('miniorange_oauth_client_email_attr_val', $email_attr)->save();
      \Drupal::configFactory()->getEditable('miniorange_oauth_client.settings')->set('miniorange_oauth_client_name_attr_val', $name_attr)->save();

      \Drupal::configFactory()->getEditable('miniorange_oauth_client.settings')->set('miniorange_oauth_client_appval',$app_values)->save();
      \Drupal::messenger()->addMessage(t('Attribute Mapping saved successfully. Please logout and go to your Drupal site’s login page, you will automatically find a <b>Login with ' . $app_name . '</b> link there.'),'status');
  }

    function clear_attr_list(&$form,$form_state){
        \Drupal::configFactory()->getEditable('miniorange_oauth_client.settings')->clear('miniorange_oauth_client_attr_list_from_server')->save();
        Utilities::show_attr_list_from_idp($form, $form_state);
    }

    public static function setup_call(array &$form, FormStateInterface $form_state){
        Utilities::schedule_a_call($form, $form_state);
    }

    public function miniorange_oauth_client_table_data_mapping($key, $value, $options, $config, $other_email_attr, $other_name_attr): array {

        if ($key == 'email_attr') {
            $row[$key] = [
                '#markup' => '<div class="mo-mapping-floating"><strong>Email Attribute: </strong></div>',
            ];

            $row['miniorange_oauth_client_email_select'] = [
                '#type' => 'select',
                '#id' => 'miniorange_oauth_client_email_select',
                '#default_value' => $config->get($value),
                '#options' => $options,
            ];

            $row['miniorange_oauth_client_email_attr'] = [
                '#type' => 'textfield',
                '#default_value' => $other_email_attr,
                '#id' => 'miniorange_oauth_client_other_field_for_email',
                '#attributes' => array('placeholder' => 'Enter Email Attribute'),
                '#states' => [
                    'visible' => [
                        ':input[id="miniorange_oauth_client_email_select"]' => ['value' => 'other'],
                    ],
                ],
                '#prefix' => '<div class="mo_oauth_attr_mapping_select_element">',
                '#suffix' => '</div></div>',
            ];
        }else{
            $row[$key] = [
                '#markup' => '<div class="mo-mapping-floating"><strong>Username Attribute: </strong></div>',
            ];

            $row['miniorange_oauth_client_username_select'] = [
                '#type' => 'select',
                '#id' => 'miniorange_oauth_client_username_select',
                '#default_value' => $config->get($value),
                '#options' => $options,
            ];

            $row['miniorange_oauth_client_name_attr'] = [
                '#type' => 'textfield',
                '#default_value' => $other_name_attr,
                '#id' => 'miniorange_oauth_client_other_field_for_name',
                '#attributes' => array('placeholder' => 'Enter Username Attribute'),
                '#states' => [
                    'visible' => [
                        ':input[id="miniorange_oauth_client_username_select"]' => ['value' => 'other'],
                    ],
                ],
                '#prefix' => '<div class="mo_oauth_attr_mapping_select_element">',
                '#suffix' => '</div>',
            ];
        }
        return $row;
    }

}

==> miniorange_oauth_client-4.0.3.tar.gz: miniorange_oauth_client/src/Form/MiniorangeMapping.php <==
<?php

/**
 * @file
 * Contains \Drupal\miniorange_oauth_client\Form\MiniorangeGeneralSettings.
 */

namespace Drupal\miniorange_oauth_client\Form;
use Drupal\Component\Serialization\Json;
use Drupal\Core\Form\FormStateInterface;
use Drupal\miniorange_oauth_client\Utilities;
use Drupal\Core\Form\FormBase;

class MiniorangeMapping extends FormBase
{

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'miniorange_mapping';
  }


  public function buildForm(array $form, FormStateInterface $form_state)
  {
      global $base_url;

      $form['markup_library'] = array(
        '#attached' => array(
            'library' => array(
                "miniorange_oauth_client/miniorange_oauth_client.admin",
                "miniorange_oauth_client/miniorange_oauth_client.style_settings",
                "miniorange_oauth_client/miniorange_oauth_client.Vtour",
                "miniorange_oauth_client/miniorange_oauth_client.slide_support_button",
            )
        ),
      );

      $config = \Drupal::config('miniorange_oauth_client.settings');

      $form['header_top_style_1'] = array('#markup' => '<div class="mo_oauth_table_layout_1">');

      $form['markup_top'] = array(
          '#markup' => '<div class="mo_oauth_table_layout mo_oauth_container_63">',
      );

      $form['markup_top_vt_start'] = array(
        '#type' => 'fieldset',
        '#title' => t('Attribute Mapping'),
      );

      $url_path = $base_url . '/' . \Drupal::service('extension.list.module')->getPath('miniorange_oauth_client'). '/includes/images';

      $email_attr = $config->get('miniorange_oauth_client_email_attr_val');
      $name_attr = $config->get('miniorange_oauth_client_name_attr_val');

      $form['markup_top_vt_start']['mo_vt_id_start1'] = array(
          '#markup' => '<hr><br>
            <div class="mo_oauth_highlight_background_note_1">Attributes are the user details that are stored by your OAuth server(s). Attribute Mapping helps you get user attributes/fields from your OAuth server and map them to your Drupal site user attributes.</div>
            <br><b>Note: </b>Please select the attribute name with email and Username from the dropdown of Received Attribute List for successful SSO. If your desired attribute is not listed in the dropdown, please select Other in the dropdown and then enter the desired attribute in the text-field.<br><br>',
      );

      $attrs = $config->get('miniorange_oauth_client_attr_list_from_server');

      if(isset($attrs))
      $attrs = JSON::decode($attrs);
      $options = array();
      if (is_array($attrs)) {
        foreach ($attrs as $key => $value) {
          if (is_array($value)){
            foreach ($value as $key1 => $value1) {
              $options[$key1] = $key1;
            }
            continue;
          }
          $options[$key] = $key;
        }
      }
      $options['other'] = 'Other';
      $other_email_attr = $email_attr == 'other' ? $config->get('miniorange_oauth_client_other_field_for_email') : '';
      $other_name_attr = $name_attr == 'other' ? $config->get('miniorange_oauth_client_other_field_for_name') : '';
      $data = ['email_attr' => 'miniorange_oauth_client_email_attr_val', 'name_attr' => 'miniorange_oauth_client_name_attr_val'];

      $form['markup_top_vt_start']['miniorange_oauth_login_mapping'] = array(
          '#type' => 'table',
          '#responsive' => TRUE,
          '#header' => [
              t('Attributes'),
              t('Received Attribute List'),
              t('If Other selected'),
          ],
          '#attributes' => ['style' => 'border-collapse: separate;'],
      );

      foreach ($data as $key => $value) {
          $row = self::miniorange_oauth_client_table_data_mapping($key, $value, $options, $config, $other_email_attr, $other_name_attr);
          $form['markup_top_vt_start']['miniorange_oauth_login_mapping'][$key] = $row;
      }

      $form['markup_top_vt_start']['miniorange_oauth_client_attr_setup_button_2'] = array(
        '#type' => 'submit',
        '#button_type' => 'primary',
        '#value' => t('Save Configuration'),
        '#prefix' => '<br>',
        '#attributes' => array('style' => '	margin: auto; display:block; '),
        '#submit' => array('::miniorange_oauth_client_attr_setup_submit'),
      );

    $form['markup_custom_attribute'] = array(
        '#type' => 'details',
        '#open' => TRUE,
        '#title' => t('Custom Attribute Mapping <a href="licensing"><img class="mo_oauth_pro_icon1" src="' . $url_path . '/pro.png" alt="Premium and Enterprise"><span class="mo_pro_tooltip">Available in the Standard, Premium and Enterprise version</span></a><a class="mo_oauth_client_how_to_setup" href="https://developers.miniorange.com/docs/oauth-drupal/mapping#attribute-mapping" target="_blank">[What is Attribute Mapping and How to Set up]</a>'),

      );

      $form['markup_custom_attribute']['attribute_mapping_info'] = array(
      '#markup' => t('<hr><br><div class="mo_oauth_highlight_background_note_1"> In addition to the default email and username attributes, the functionality of custom attribute mapping is provided in the <a href="' . $base_url . '/admin/config/people/miniorange_oauth_client/licensing">Standard, Premium and Enterprise</a> version of the module. One can map fields like contact number, first name, last name or any other attribute using the custom attribute mapping feature.</div>')
    );

      $form['markup_custom_attribute']['markup_cam'] = array(
        '#markup' => '<br><div class="mo_oauth_highlight_background_note_1">One should note that the attribute name has to be the machine name assigned automatically and not the Label of the attribute. </div><br>',
      );

      $form['markup_custom_attribute']['miniorange_oauth_attr_name'] = array(
          '#type' => 'textfield',
          '#prefix' => '<div><table><tr><td>',
          '#suffix' => '</td>',
          '#id' => 'text_field1',
          '#title' => t('OAuth Server Attribute Name 1'),
          '#attributes' => array('style' => 'width:73%;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'OAuth Server Attribute Name'),
          '#required' => FALSE,
          '#disabled' => TRUE,
      );
      $form['markup_custom_attribute']['miniorange_oauth_server_name'] = array(
          '#type' => 'textfield',
          '#id' => 'text_field2',
          '#prefix' => '<td>',
          '#suffix' => '</td>',
          '#title' => t('Attribute Name 1'),
          '#attributes' => array('style' => 'width:73%;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Enter Attribute Name'),
          '#required' => FALSE,
          '#disabled' => TRUE,
      );
      $form['markup_custom_attribute']['miniorange_oauth_add_name'] = array(
          '#prefix' => '<td>',
          '#suffix' => '</td>',
          '#type' => 'button',
          '#disabled' => 'true',
          '#button_type' => 'primary',
          '#value' => '+',
      );
      $form['markup_custom_attribute']['miniorange_oauth_sub_name'] = array(
          '#prefix' => '<td>',
          '#suffix' => '</td></tr></table></div>',
          '#type' => 'button',
          '#disabled' => 'true',
          '#value' => '-',
      );

    $form['markup_custom_role_mapping'] = array(
        '#type' => 'details',
        '#open' => TRUE,
        '#title' => t('Custom Role Mapping <a href="licensing"><img class="mo_oauth_pro_icon1" src="' . $url_path . '/pro.png" alt="Premium and Enterprise"><span class="mo_pro_tooltip">Available in the Premium and Enterprise version</span></a><a class="mo_oauth_client_how_to_setup" href="https://developers.miniorange.com/docs/oauth-drupal/mapping#role-mapping" target="_blank">[What is Role Mapping and How to Set up]</a>'),

    );

      $form['markup_custom_role_mapping']['miniorange_disable_attribute'] = array(
        '#type' => 'checkbox',
        '#title' => t('Do not update existing user&#39;s role.'),
	    '#disabled' => TRUE,
        '#prefix' => '<br>',
      );

      $form['markup_custom_role_mapping']['miniorange_oauth_disable_role_update'] = array(
        '#type' => 'checkbox',
        '#title' => t('Check this option if you do not want to update user role if roles not mapped.'),
	    '#disabled' => TRUE,
      );

      $mrole= user_role_names($membersonly = TRUE);
      $drole = array_values($mrole);

      $form['markup_custom_role_mapping']['miniorange_oauth_default_mapping'] = array(
          '#type' => 'select',
          '#id' => 'miniorange_oauth_client_app',
          '#title' => t('Select default group for the new users'),
          '#options' => $mrole,
          '#default_value' => $drole,
          '#attributes' => array('style' => 'width:73%;'),
          '#disabled' => TRUE,
      );

      foreach($mrole as $roles) {
          $rolelabel = str_replace(' ','',$roles);
          $form['markup_custom_role_mapping']['miniorange_oauth_role_' . $rolelabel] = array(
              '#type' => 'textfield',
              '#title' => t($roles),
              '#default_value' => \Drupal::config('miniorange_oauth_client.settings')->get('miniorange_oauth_role_' . $rolelabel, ''),
              '#attributes' => array('style' => 'width:73%;background-color: hsla(0,0%,0%,0.08) !important;','placeholder' => 'Semi-colon(;) separated Group/Role value for ' . $roles),
              '#disabled' => TRUE,
          );
      }

      $form['miniorange_oauth_client_attr_setup_button'] = array(
        '#type' => 'submit',
        '#button_type' => 'primary',
        '#value' => t('Save Configuration'),
        '#attributes' => array('style' => '	margin: auto; display:block; '),
        '#disabled' => TRUE,
      );
      $form['mo_header_style_end'] = array('#markup' => '</div>');
      Utilities::show_attr_list_from_idp($form, $form_state);

      $form['miniorange_idp_guide_link_end'] = array(
          '#markup' => '</div>',
      );

      Utilities::moOAuthShowCustomerSupportIcon($form, $form_state);

      return $form;
  }

  public function submitForm(array &$form, FormStateInterface $form_state) {

  }

  function miniorange_oauth_client_attr_setup_submit($form, $form_state)
  {
      $form_values = $form_state->getValues();
      $email_attr = $form_values['miniorange_oauth_login_mapping']['email_attr']['miniorange_oauth_client_email_select'];
      $name_attr = $form_values['miniorange_oauth_login_mapping']['name_attr']['miniorange_oauth_client_username_select'];
      $app_name = \Drupal::config('miniorange_oauth_client.settings')->get('miniorange_auth_client_app_name');

      $app_values = \Drupal::config('miniorange_oauth_client.settings')->get('miniorange_oauth_client_appval');

      if ($email_attr == 'other'){
         $other_email_attr = trim($form_values['miniorange_oauth_login_mapping']['email_attr']['miniorange_oauth_client_email_attr']);
         $app_values['miniorange_oauth_client_email_attr'] = $other_email_attr;
         \Drupal::configFactory()->getEditable('miniorange_oauth_client.settings')->set('miniorange_oauth_client_other_field_for_email', $other_email_attr)->save();
      }
      else{
        $app_values['miniorange_oauth_client_email_attr'] = $email_attr;
      }

      if ($name_attr == 'other'){
        $other_name_attr = trim($form_values['miniorange_oauth_login_mapping']['name_attr']['miniorange_oauth_client_name_attr']);
        $app_values['miniorange_oauth_client_name_attr'] = $other_name_attr;
        \Drupal::configFactory()->getEditable('miniorange_oauth_client.settings')->set('miniorange_oauth_client_other_field_for_name', $other_name_attr)->save();
      }
      else{
        $app_values['miniorange_oauth_client_name_attr'] = $name_attr;
      }


      \Drupal::configFactory()->getEditable('miniorange_oauth_client.settings')->set('miniorange_oauth_client_email_attr_val', $email_attr)->save();
      \Drupal::configFactory()->getEditable('miniorange_oauth_client.settings')->set('miniorange_oauth_client_name_attr_val', $name_attr)->save();

      \Drupal::configFactory()->getEditable('miniorange_oauth_client.settings')->set('miniorange_oauth_client_appval',$app_values)->save();
      \Drupal::messenger()->addMessage(t('Attribute Mapping saved successfully. Please logout and go to your Drupal site’s login page, you will automatically find a <b>Login with ' . $app_name . '</b> link there.'),'status');
  }

    function clear_attr_list(&$form,$form_state){
        \Drupal::configFactory()->getEditable('miniorange_oauth_client.settings')->clear('miniorange_oauth_client_attr_list_from_server')->save();
        Utilities::show_attr_list_from_idp($form, $form_state);
    }

    public function miniorange_oauth_client_table_data_mapping($key, $value, $options, $config, $other_email_attr, $other_name_attr): array {

        if ($key == 'email_attr') {
            $row[$key] = [
                '#markup' => '<div class="mo-mapping-floating"><strong>Email Attribute: </strong></div>',
            ];

            $row['miniorange_oauth_client_email_select'] = [
                '#type' => 'select',
                '#id' => 'miniorange_oauth_client_email_select',
                '#default_value' => $config->get($value),
                '#options' => $options,
            ];

            $row['miniorange_oauth_client_email_attr'] = [
                '#type' => 'textfield',
                '#default_value' => $other_email_attr,
                '#id' => 'miniorange_oauth_client_other_field_for_email',
                '#attributes' => array('placeholder' => 'Enter Email Attribute'),
                '#states' => [
                    'visible' => [
                        ':input[id="miniorange_oauth_client_email_select"]' => ['value' => 'other'],
                    ],
                ],
                '#prefix' => '<div class="mo_oauth_attr_mapping_select_element">',
                '#suffix' => '</div></div>',
            ];
        }else{
            $row[$key] = [
                '#markup' => '<div class="mo-mapping-floating"><strong>Username Attribute: </strong></div>',
            ];

            $row['miniorange_oauth_client_username_select'] = [
                '#type' => 'select',
                '#id' => 'miniorange_oauth_client_username_select',
                '#default_value' => $config->get($value),
                '#options' => $options,
            ];

            $row['miniorange_oauth_client_name_attr'] = [
                '#type' => 'textfield',
                '#default_value' => $other_name_attr,
                '#id' => 'miniorange_oauth_client_other_field_for_name',
                '#attributes' => array('placeholder' => 'Enter Username Attribute'),
                '#states' => [
                    'visible' => [
                        ':input[id="miniorange_oauth_client_username_select"]' => ['value' => 'other'],
                    ],
                ],
                '#prefix' => '<div class="mo_oauth_attr_mapping_select_element">',
                '#suffix' => '</div>',
            ];
        }
        return $row;
    }
}
//'<span class="mo_pro_tooltip">Available in the Premium and Enterprise version</span>,
